@@ -4,9 +4,9 @@ dmzsm <- function(x, J, theta, log = FALSE){
 	mzsm <- function(y, J, theta) (theta/y)*(1-y/J)^(theta-1)
 	sn <- mzsm(y=x, J = J, theta = theta)
 	mu <- mzsm(y=1:J, J = J, theta = theta)
-	lpn <- log(sn) - log(sum(mu))
+	lpn <- suppressWarnings(log(sn) - log(sum(mu))) # Might be NaN if x > 0, but end result will be zero
+        lpn[ x <= 0 | x > J ] <- -Inf
 	if (any(is.nan(lpn))) warning ("NaNs produced")
-	lpn[ x <= 0] <- -Inf
 	if(log) return(lpn)
 	else return(exp(lpn))
 }
