@@ -18,5 +18,5 @@ fitpareto <- function(x, trunc, start.value, upper = 20, ...){
                  data = list(x = x), method = "Brent", lower = 0, upper = upper), dots))
   if(abs(as.numeric(result@coef) - upper) < 0.001) 
     warning("mle equal to upper bound provided. \n Try value for the 'upper' argument")
-  new("fitsad", result, sad="pareto", distr = "C", trunc = ifelse(missing(trunc), NaN, trunc)) 
+  new("fitsad", result, sad="pareto", distr = distr.depr, trunc = ifelse(missing(trunc), NaN, trunc)) 
 }
