@@ -20,12 +20,18 @@ octav <- function(x, oct, preston=FALSE){
   N <- 2^(oct)
   oct.hist <- hist(y, breaks=c(0,N), plot=FALSE)
   res <- data.frame(octave = oct, upper = oct.hist$breaks[-1], Freq = oct.hist$counts)
-  if(preston){
-    j <- N[-length(N)]
-    w <- y[y%in%j]
-    ties <- table(factor(w, levels=j))
-    res[-1, 3] <- res[-1, 3]+ties/2
-    res[-length(N), 3] <- res[-length(N), 3]-ties/2
-  }
+  if(preston) res <- prestonfy(res, y)
   new("octav", res)
 }
+
+# Helper function to create Preston octaves. Is also used by octavpred
+prestonfy <- function(res, y) {
+  N <- 2^(res$octave)
+  j <- N[-length(N)]
+  w <- y[y%in%j]
+  ties <- table(factor(w, levels=j))
+  res[-1, 3] <- res[-1, 3]+ties/2
+  res[-length(N), 3] <- res[-length(N), 3]-ties/2
+  return(res)
+}
+
